/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: Pops, TCSDeveloper
 */

using System;
using System.Drawing;
using System.Drawing.Drawing2D;

namespace TopCoder.Rules.DependencyMap.View
{

    /// <summary>
    /// This interface defines the methods that the ILayoutManager will be needed to 'paint' the diagram to some
    /// source.
    /// </summary>
    public interface IGraphics : IDisposable
    {

        /// <summary>
        /// This method should draw the GraphicsPath using the specified Pen.
        /// </summary>
        /// <param name="pen">The pen to use</param>
        /// <param name="path">The path to draw</param>
        /// <exception cref="ArgumentNullException">if either argument is null</exception>
        void DrawPath(Pen pen, GraphicsPath path);

        /// <summary>
        /// This method should draw the specified text at the specified point using the specified font and brush.
        /// </summary>
        /// <param name="text">The text to draw</param>
        /// <param name="font">The font to use int drawing the text</param>
        /// <param name="brush">The brush to use in drawing the text</param>
        /// <param name="point">The point were the text should be drawn</param>
        /// <exception cref="ArgumentNullException">if any argument is null</exception>
        void DrawString(string text, Font font, Brush brush, PointF point);

        /// <summary>
        /// This method will measure the text height and width when drawn using the specified font using this
        /// graphics context. The size of the text will then be returned to the caller.
        /// </summary>
        /// <param name="text">The text that should be measured</param>
        /// <param name="font">The font to use when drawing</param>
        /// <returns>The size of the text</returns>
        /// <exception cref="ArgumentNullException">if any argument is null</exception>
        SizeF MeasureString(string text, Font font);

        /// <summary>
        /// This method will be called by the DiagramRenderer when rendering has been fully completed (successfully)
        /// and allows implementations to finish any pending processing that they may need to do (such as saving
        /// files). This method will only be called if the rendering process has been completed successfully.
        /// </summary>
        /// <exception cref="RendererException">if an exception occurs during completion</exception>
        void Complete();

    }

}
