/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: Pops, TCSDeveloper
 */

using System;

namespace TopCoder.Rules.DependencyMap.View
{

    /// <summary>
    /// This class represents an exception that is thrown during the rendering process and will contain a reason
    /// and potentially an embedded exception.
    /// </summary>
    public class RendererException : Exception
    {

        /// <summary>
        /// Creates the exception by calling the super constructor with the same parameter.
        /// </summary>
        /// <param name="reason">The reason for the exception</param>
        /// <exception cref="ArgumentNullException">if reason is null</exception>
        /// <exception cref="ArgumentException">if reason is empty (trim'd)</exception>
        public RendererException(string reason) : base(reason)
        {
            if (reason == null)
            {
                throw new ArgumentNullException("reason");
            }
            if (reason.Trim() == string.Empty)
            {
                throw new ArgumentException("reason should not be null.");
            }
        }

        /// <summary>
        /// Creates the exception by calling the super constructor with the same parameters.
        /// </summary>
        /// <param name="reason">The reason for the exception</param>
        /// <param name="cause">A, potentially null, related exception that caused it</param>
        /// <exception cref="ArgumentNullException">if reason is null</exception>
        /// <exception cref="ArgumentException">if reason is empty (trim'd)</exception>
        public RendererException(string reason, Exception cause) : base(reason, cause)
        {
            if (reason == null)
            {
                throw new ArgumentNullException("reason");
            }
            if (reason.Trim() == string.Empty)
            {
                throw new ArgumentException("reason should not be null.");
            }
            if (cause == null)
            {
                throw new ArgumentNullException("cause");
            }
        }

    }

}
