/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDeveloper
 */

using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.Rules.DependencyMap.View
{   
    /// <summary>
    /// Failure test fixture for Dependency.
    /// </summary>
    [TestFixture]
    public class DependencyTests
    {
        /// <summary>
        /// Test constructor with null title.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testCon_Null() 
        {
            new Dependency(null);
        }

        /// <summary>
        /// Test constructor with null title.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testCon_Null2() 
        {
            new Dependency(null, 123);
        }

        /// <summary>
        /// Test constructor with empty title.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentException))]
        public void testCon_Empty() 
        {
            new Dependency("     ", 123);
        }

        /// <summary>
        /// Test constructor with empty title.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentException))]
        public void testCon_Neg() 
        {
            new Dependency("     ");
        }

        /// <summary>
        /// Test constructor with inv value.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon_Inv() 
        {
            new Dependency("greg", 0);
        }

        /// <summary>
        /// Test constructor.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentOutOfRangeException))]
        public void testCon_Inv2() 
        {
            new Dependency("greg", -12);
        }
    

        /// <summary>
        /// Test constructor.
        /// </summary>
        [Test]
        public void testCon_Silent() 
        {
            new Dependency("greg", -1);
        }
    
        /// <summary>
        /// Test add with null.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testSet_Null() 
        {
            new Dependency("greg", 123)[null] = new Dependency("greg");
        }      

        /// <summary>
        /// Test add with null.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testSet_Null2() 
        {
            new Dependency("greg", 123)["greg"] = null;
        }      

        /**
         * Test constructor.
         */
        [Test]
        public void testSet_Silent() 
        {
            new Dependency("greg", 123)["Greggy"] = new Dependency("Greggy", -1);
        }
    }
}
