/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view;

import junit.framework.TestCase;
import java.awt.geom.GeneralPath;

/**
 * Unit test cases for ShapeFactory.
 *
 * Testing of ShapeFactory includes simple test of the setter and getter as well as the predefined shapes.
 *
 * @author TCSDeveloper
 */
public class ShapeFactoryUnitTests extends TestCase {

    /**
     * The type to work with.
     */
    private int type = 18;

    /**
     * The shape to work with.
     */
    private GeneralPath shape;

    /**
     * ShapeFactory instance to test.
     */
    private ShapeFactory factory = null;

    /**
     * Create a new factory instance for each test.
     */
    protected void setUp() {
        factory = new ShapeFactory();

        shape = new GeneralPath();
        shape.moveTo(14, 27);
        shape.lineTo(43, 77);
        shape.lineTo(21, 30);
        shape.closePath();
    }

    /**
     * Create instance.
     */
    public void testCreate() {
        factory = new ShapeFactory();
        assertNotNull("Relationship arrow not set.",
                factory.getShape(ShapeFactory.RELATIONSHIP_ARROW));
        assertNotNull("Unseen element not set.",
                factory.getShape(ShapeFactory.UNSEEN_ELEMENT));
        assertNotNull("Seen element not set.",
                factory.getShape(ShapeFactory.SEEN_ELEMENT));
    }

    /**
     * Test setShape().
     */
    public void testSetShape() {
        assertNull("Prior value assigned.", factory.setShape(type, shape));
        assertEquals("Shape mismatches.", shape.getBounds(), factory.getShape(type).getBounds());

        assertEquals("Prior value not assigned.", shape.getBounds(), factory.setShape(type, shape).getBounds());
    }

    /**
     * Test setShape() with invalid type.
     */
    public void testSetShape_InvalidType() {
        try {
            factory.setShape(0, shape);
            fail("Should have thrown IllegalArgumentException.");
        } catch (IllegalArgumentException iae) {
        }
    }

    /**
     * Test setShape() with null shape.
     */
    public void testSetShape_NullShape() {
        try {
            factory.setShape(type, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) {
        }
    }

    /**
     * Test getShape().
     */
    public void testGetShape() {
        assertNull("Shape returned for unknown type.", factory.getShape(type));

        factory.setShape(type, shape);
        assertEquals("Shape mismatches.", shape.getBounds(), factory.getShape(type).getBounds());
    }

    /**
     * Test getShape() with invalid type.
     */
    public void testGetShape_InvalidType() {
        try {
            factory.getShape(0);
            fail("Should have thrown IllegalArgumentException.");
        } catch (IllegalArgumentException iae) {
        }
    }

    /**
     * Test removeShape().
     */
    public void testRemoveShape() {
        factory.setShape(type, shape);
        assertEquals("Shape mismatches.", shape, factory.removeShape(type));
        assertNull("Shape returned for unknown type.", factory.removeShape(type));
    }

    /**
     * Test removeShape() with invalid type.
     */
    public void testRemoveShape_InvalidType() {
        try {
            factory.removeShape(0);
            fail("Should have thrown IllegalArgumentException.");
        } catch (IllegalArgumentException iae) {
        }
    }

    /**
     * Test removeShape() with predefined type.
     */
    public void testRemoveShape_PredefinedType() {
        try {
            factory.removeShape(ShapeFactory.RELATIONSHIP_ARROW);
            fail("Should have thrown IllegalArgumentException.");
        } catch (IllegalArgumentException iae) {
        }
    }

}
