/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view.accuracytests;

import java.awt.Insets;
import java.io.File;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import com.topcoder.rules.dependencymap.view.Dependency;
import com.topcoder.rules.dependencymap.view.DependencyRenderer;
import com.topcoder.rules.dependencymap.view.DiagramRenderer;
import com.topcoder.rules.dependencymap.view.FixedGridLayoutManager;
import com.topcoder.rules.dependencymap.view.RendererException;
import com.topcoder.rules.dependencymap.view.SVGRenderer;
import com.topcoder.rules.dependencymap.view.ShapeFactory;

/**
 * Test creating different maps for accuracy.
 *
 * @author cucu
 * @version 1.0
 */
public class AccuracyTests extends TestCase {
	protected DependencyRenderer renderer = null;
    protected DiagramRenderer diagramRenderer = null;
    protected Dependency a = null;
    protected Dependency b = null;
    protected Dependency c = null;
    protected Dependency d = null;
    protected Dependency e = null;
    protected Dependency f = null;
    protected Dependency g = null;
    /**
     * Return the test suite.
     *
     * @return the test suite.
     */
    public static Test suite() {
        final TestSuite suite = new TestSuite();
        suite.addTestSuite(AccuracyTests.class);

        return suite;
    }
    /**
     * Set up for each test.
     */
    public void setUp() {
        renderer = new DependencyRenderer();

        a = new Dependency("A");
        b = new Dependency("B");
        c = new Dependency("C");
        d = new Dependency("D");
        e = new Dependency("E");
        f = new Dependency("F");
        g = new Dependency("G");
    }

   /**
     *  Test overriding a shape.
     */
    public void testShapeOverride() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testShapeOverride.svg")));
        a = new Dependency("A", ShapeFactory.SEEN_ELEMENT);
        renderer.render(a);
    }

    /**
     * Test drawing only one dependency
     *
     * @throws rendererException
     */
    public void testOneDependency() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testOneDependency.svg")));
        renderer.render(a);
    }

    /**
     *  Test overriding the default padding and margin and using a different text size.
     */
    public void testPaddingMarginAndSize() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testPaddingMarginAndSize.svg")));
        String text = "this is a Padding and Margin test";
        a = new Dependency(text);
        Insets insets = new Insets(5, 10, 15, 20);
        renderer.setLayoutManager(new FixedGridLayoutManager(37, 49, insets));
        renderer.render(a);

    }

    /**
     *  Test A that depends on B
     *   A
     *   |
     *   B
     */
    public void testOneChild() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testOneChild.svg")));
        a.addDependant(b);
        renderer.render(a);

    }

    /**
     * Test A that depends on B and C
     *    A
     *   / \
     *  B   C
     */
    public void testTwoChild() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testTwoChild.svg")));
        a.addDependant(b);
        a.addDependant(c);
        renderer.render(a);

    }

    /**
     * Test A that depends on B, C and D
     *    A
     *   /|\
     *  B C D
    */
    public void testTreeChild() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testTreeChild.svg")));
        a.addDependant(b);
        a.addDependant(c);
        a.addDependant(d);
        renderer.render(a);
    }

    /**
     * Test a chain of 4 dependencies.
     *    A
     *    |
     *    B
     *    |
     *    C
     *    |
     *    D
    */
    public void testChain() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testChain.svg")));
        a.addDependant(b);
        b.addDependant(c);
        c.addDependant(d);
        renderer.render(a);

    }
    /**
     * Test the dependencies as the figure 2 of the specification:
     *      A
     *    /   \
     *    B    E
     *   / \   |
     *  C   D  F
    */
    public void testSpec1() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testSpec1.svg")));
        a.addDependant(b);
        a.addDependant(e);
        b.addDependant(c);
        b.addDependant(d);
        e.addDependant(f);
        renderer.render(a);
    }

    /**
     * Test the dependencies as the figure 6 of the specification:
     *      A
     *    /   \
     *    B    C
     *  // \
     * D E  F
     *   |  /\
     *   F G C
    */
    public void testSpec2() throws RendererException {
        renderer.addDiagramRenderer(new SVGRenderer(new File("test_files\\accuracytests\\testSpec2.svg")));
        a.addDependant(b);
        a.addDependant(c);
        b.addDependant(d);
        b.addDependant(e);
        b.addDependant(f);
        e.addDependant(f);
        f.addDependant(g);
        f.addDependant(c);
        renderer.render(a);
    }
    
}




